/**********************************************************************
 * group.c                                                 October 2002
 * Horms                                             horms@verge.net.au
 *
 * Encapsulation of a Multicast Group
 *
 * libvaness_mcast
 * Multicast Helper Library
 * Copyright (C) 2000 Horms
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 * 02111-1307  USA
 *
 **********************************************************************/

#include <sys/types.h>
#include <sys/socket.h>
#include <arpa/inet.h>
#include <vanessa_logger.h>
#include <vanessa_socket.h>

#include "vanessa_mcast.h"


/**********************************************************************
 * vanessa_mcast_group_test
 * Test to see if an alleged group is in fact a multicast group
 *
 * pre: group: alleged group: may be an ip address or hostname
 *      flag: passed to vanessa_socket_host_in_addr
 * return: 1 if group is a multicast grou[
 *         0 if it is not
 *         -1 on error
 **********************************************************************/

int vanessa_mcast_group_test(const char *group, unsigned int flag)
{
	struct in_addr addr;

	if (vanessa_socket_host_in_addr(group, &addr, flag) < 0) {
		VANESSA_LOGGER_DEBUG("vanessa_socket_host_in_addr");
		return(-1);
	}

	return(IN_MULTICAST(ntohl(addr.s_addr))?1:0);
}

